@@ -1,6 +1,6 @@
 #include "arg.ih"
 
-void Arg::addCharOption()
+void Arg__::addCharOption()
 {
     d_optv[d_getOpt].push_back(optarg ? optarg : "");
     ++d_nOptv;
