@@ -3,7 +3,7 @@
 Arg &Arg::instance()
 {
     if (!s_arg)
-        throw Exception() << "Arg::instance(): not yet initialized";
+        throw Exception{} << "Arg::instance(): not yet initialized";
 
     return *s_arg;
 }
