@@ -3,6 +3,6 @@
 LongOption__::LongOption__(char const *name)
 :
     d_name(name),
-    d_type(None),
-    d_optionChar(0)        
+    d_type(NoArg),
+    d_optionChar(0)
 {}
