@@ -6,11 +6,12 @@ ArgConfig &ArgConfig::initialize(char const *optstring,
                              int argc, char **argv,
                              Comment cType, SearchCasing sType, Indices iType)
 {
-    if (s_argconfig)
+    if (s_argConfig)
         throw Exception{} << s_alreadyInitialized;
 
-    s_argconfig = new ArgConfig(0, optstring, 0, 0, argc, argv,
-                                cType, sType, iType);
+    s_argConfig.reset(new ArgConfig{ 0, optstring, 0, 0, argc, argv,
+                                     cType, sType, iType }
+                     );
 
-    return *s_argconfig;
+    return *s_argConfig;
 }
