@@ -6,13 +6,13 @@ ArgConfig &ArgConfig::initialize(int accept, char const *optstring,
                 int argc, char **argv,
                 Comment cType, SearchCasing sType, Indices iType)
 {
-    if (s_argconfig)
+    if (s_argConfig)
         throw Exception{} << s_alreadyInitialized;
 
-    s_argconfig = new ArgConfig(accept, optstring,
-                            0, 0,
-                            argc, argv,
-                            cType, sType, iType);
-
-    return *s_argconfig;
+    s_argConfig.reset(new ArgConfig{ accept, optstring,
+                                     0, 0,
+                                     argc, argv,
+                                     cType, sType, iType }
+                     );
+    return *s_argConfig;
 }
