@@ -1,6 +1,6 @@
 #include "bigint.ih"
 
-BigInt const BigInt::gcdc(BigInt const &rhs) const
+BigInt BigInt::gcdc(BigInt const &rhs) const
 {
     BigInt ret(*this);
     ret.gcd(rhs);
