@@ -4,8 +4,8 @@ BigInt &BigInt::sqr()
 {
     BNCTX ctx;
 
-    if (BN_sqr(&d_bn, &d_bn, ctx) != 1)
-        throw Errno("BigInt sqr() failed");
+    if (BN_sqr(d_bn, d_bn, ctx) != 1)
+        throw Exception{} << "BigInt sqr() failed";
 
     return *this;
 }
