@@ -8,11 +8,17 @@ size_t CGIFSA::wordToken()
         d_buffer += d_in.get();
 
     if (!d_buffer.size())               // if none read, return the next char
-        return charToken();             
+        return charToken();
 
                                         // look for a character class name
-    PairCPPFunP const *ret = find_if(s_charClass, s_charClassEnd, 
-            FnWrap::unary(isFirst, d_buffer));
+    PairCPPFunP const *ret =
+            find_if(
+                s_charClass, s_charClassEnd,
+                [&](PairCPPFunP const &cClass)
+                {
+                    return d_buffer == cClass.first;
+                }
+            );
 
     if (ret == s_charClassEnd)          // no character class found
         return static_cast<unsigned char>(*d_buffer.rbegin());
@@ -21,4 +27,3 @@ size_t CGIFSA::wordToken()
 
     return SET;                         // return `set found'
 }
-
