@@ -1,9 +1,8 @@
-//#include <bobcat/cininserter>
-#include "../cininserter"
-
 #include <iostream>
 #include <fstream>
 
+#include <bobcat/cininserter>
+
 using namespace std;
 using namespace FBB;
 
