@@ -1,6 +1,6 @@
 #include "configfile.ih"
 
-ConfigFile::RE_iteratorPair ConfigFile::beginEndRE()
+ConfigFile::RE_iteratorPair ConfigFile::beginEndRE() const
 {
     return RE_iteratorPair(d_ptr->endRE(), d_ptr->endRE());
 }
