@@ -1,4 +1,4 @@
-inline DateTime DateTime::thisTime() const
+inline FBB::DateTime FBB::DateTime::thisTime() const
 {
     return DateTime{ d_utcSec, LOCALTIME };     // the computer's local time
 }
