@@ -1,5 +1,5 @@
     // at this point DST is known to be active (cf. utcFromTM)
-inline int DateTime::Zone::dstSeconds() const
+inline int FBB::DateTime::Zone::dstSeconds() const
 {
     return d_data.dstSeconds;
 }
