@@ -1,10 +1,7 @@
-/*
-                              driver.cc
-*/
+#include <iostream>
 
 #include <bobcat/exception>
 #include <bobcat/level>
-#include <iostream>
 
 using namespace std;
 using namespace FBB;
