@@ -1,7 +1,7 @@
 //         Value &at(Key const &key);
 
-template <typename Key, typename Value, typename Alloc>
-Value &LinearMap<Key, Value, Alloc>::at(Key const &key)
+template <typename Key, typename Value>
+Value &LinearMap<Key, Value>::at(Key const &key)
 {
     auto iter = find(key);
     if (iter == end())
