@@ -1,4 +1,4 @@
-inline MailHeaders::const_hdr_iterator MailHeaders::beginh() const
+inline FBB::MailHeaders::const_hdr_iterator FBB::MailHeaders::beginh() const
 {
     return const_hdr_iterator(this, begin());
                                         // returns iterator over all headers
