@@ -14,7 +14,7 @@
 // x GB specifications. Prepare for segments having room for about 
 //      0.5 GB = 131'072 pages
 
-    //  by memorybuf/memorybuf3.cc
+    //  by memorybuf/memorybuf3.cc, memoryaccess/create.cc
     
 MemoryBridge::MemoryBridge(string const &bufSize, bool erase, size_t access)
 :   
@@ -24,6 +24,7 @@ MemoryBridge::MemoryBridge(string const &bufSize, bool erase, size_t access)
 //xerr("Creating MemoryAccess");
                                                 // get the MemoryAccess
     d_accessPtr = MemoryAccess::create(bufSize, access);
-    d_access = &MemoryBridge::available;   // requireAccess() now returns 
-                                            // a reference to the 
+
+    d_access = &MemoryBridge::available;    // requireAccess() now returns a
+                                            // reference to the shared memory
 }
