@@ -5,7 +5,7 @@
 
 MemoryBridge::MemoryBridge(int id, bool erase)
 :
-    d_accessPtr(MemoryAccess::loadID(id)),
+    d_accessPtr(MemoryAccess::loadID(id)),  // ptr to ID's shared memory
     d_erase(erase),
-    d_access(&MemoryBridge::available)
+    d_access(&MemoryBridge::available)      // public access to d_accessPtr
 {}
