@@ -1,4 +1,4 @@
-inline void OFoldBuf::useBlanks()
+inline void FBB::OFoldBuf::useBlanks()
 {
     d_indentChar = ' ';
     d_indentWidth = 1;
