@@ -1,4 +1,4 @@
-inline void OFoldBuf::writeNonWs() const
+inline void FBB::OFoldBuf::writeNonWs() const
 {
     out().write(d_nonWs.data(), d_nonWs.length());
 }
