@@ -1,4 +1,4 @@
 inline void OFoldStream::setMargins(size_t lm, size_t rm)
 {
-    OFoldStreambuf::setMargins(lm, rm);
+    OFoldBuf::setMargins(lm, rm);
 }
