@@ -43,6 +43,6 @@ PerlSetFSA::TransitionMatrix *PerlSetFSA::s_stateTransitions_end =
         /
         sizeof(PerlSetFSA::TransitionMatrix);
 
-vector<PerlSetFSA::statePair> PerlSetFSA::s_transition;
+vector<PerlSetFSA::StatePair> PerlSetFSA::s_transition;
 
 string Pattern::Regex::s_converted;
