@@ -6,11 +6,11 @@ void PerlSetFSA::initialize(TransitionMatrix &stateDescription)
 {
                                 // statePtr points to the element matching
                                 // stateTransitions[]' element
-    statePair *statePtr = &s_transition[stateDescription.d_state];
+    StatePair *statePtr = &s_transition[stateDescription.d_state];
 
                                 // not yet initialized: both point to the
     if (!statePtr->first)       // first element in stateTransitions[]
-        *statePtr = statePair(&stateDescription, &stateDescription);
+        *statePtr = StatePair(&stateDescription, &stateDescription);
     else
        statePtr->second++;      // otherwise: there's another element: count
 }                               // the #elements of a state
