@@ -4,7 +4,7 @@ void Process::close()
 {
     d_oChildIn.flush();
 
-    closeWriteFd(d_oChildInPipe);
+    d_oChildInPipe.close();
 
     if (d_oChildIn.rdbuf() != 0)
         close(d_oChildInbuf.fd());
