@@ -1,7 +1,7 @@
 #include <iostream>
 #include <istream>
 
-#include "../randbuf"
+#include <bobcat/randbuf>
 
 using namespace std;
 using namespace FBB;
