@@ -1,6 +1,6 @@
 #include "stat.ih"
 
 Stat::Stat()
-{
-    init();
-}
+:
+    d_errno(false)
+{}
